@@ -21,6 +21,7 @@ import org.apache.linkis.common.ServiceInstance
 import org.apache.linkis.common.utils.{Logging, Utils}
 import org.apache.linkis.governance.common.conf.GovernanceCommonConf
 import org.apache.linkis.manager.am.service.engine.EngineStopService
+import org.apache.linkis.manager.am.vo.CanCreateECRes
 import org.apache.linkis.manager.common.conf.RMConfiguration
 import org.apache.linkis.manager.common.entity.enumeration.NodeStatus
 import org.apache.linkis.manager.common.entity.node.{AMEMNode, AMEngineNode, EngineNode, InfoRMNode}
@@ -33,6 +34,7 @@ import org.apache.linkis.manager.common.entity.persistence.{
 import org.apache.linkis.manager.common.entity.resource._
 import org.apache.linkis.manager.common.errorcode.ManagerCommonErrorCodeSummary
 import org.apache.linkis.manager.common.exception.{RMErrorException, RMWarnException}
+import org.apache.linkis.manager.common.protocol.engine.{EngineAskRequest, EngineCreateRequest}
 import org.apache.linkis.manager.common.utils.{ManagerUtils, ResourceUtils}
 import org.apache.linkis.manager.label.builder.factory.LabelBuilderFactoryContext
 import org.apache.linkis.manager.label.constant.LabelKeyConstant
@@ -52,6 +54,7 @@ import org.apache.linkis.manager.rm.{
   ResourceInfo,
   ResultResource
 }
+import org.apache.linkis.manager.rm.domain.RMLabelContainer
 import org.apache.linkis.manager.rm.entity.{LabelResourceMapping, ResourceOperationType}
 import org.apache.linkis.manager.rm.entity.ResourceOperationType.{LOCK, USED}
 import org.apache.linkis.manager.rm.exception.{RMErrorCode, RMLockFailedRetryException}
@@ -152,22 +155,40 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
     eMInstanceLabel.setInstance(serviceInstance.getInstance)
 
     val emResource = labelResourceService.getLabelResource(eMInstanceLabel)
+    var registerResourceFlag = true
     if (emResource != null) {
-      logger.warn(s"${serviceInstance} has been registered, now update resource.")
-      if (!emResource.getResourceType.equals(resource.getResourceType)) {
-        throw new RMErrorException(
-          RMErrorCode.LABEL_DUPLICATED.getErrorCode,
-          MessageFormat.format(
-            RMErrorCode.LABEL_DUPLICATED.getErrorDesc,
-            serviceInstance,
-            emResource.getResourceType,
-            resource.getResourceType
-          )
+      registerResourceFlag = false
+      logger.warn(s"${serviceInstance} has been registered, resource is ${emResource}.")
+      val leftResource = emResource.getLeftResource
+      if (leftResource != null && Resource.getZeroResource(leftResource).moreThan(leftResource)) {
+        logger.warn(
+          s"${serviceInstance} has been registered, but left Resource <0 need to register resource."
         )
+        registerResourceFlag = true
       }
+      val usedResource = emResource.getLockedResource.add(emResource.getUsedResource)
+      if (usedResource.moreThan(emResource.getMaxResource)) {
+        logger.warn(
+          s"${serviceInstance} has been registered, but usedResource > MaxResource  need to register resource."
+        )
+        registerResourceFlag = true
+      }
+
+      if (!(resource.getMaxResource.equalsTo(emResource.getMaxResource))) {
+        logger.warn(
+          s"${serviceInstance} has been registered, but inconsistent newly registered resources  need to register resource."
+        )
+        registerResourceFlag = true
+      }
+    }
+
+    if (!registerResourceFlag) {
+      logger.warn(s"${serviceInstance} has been registered, skip register resource.")
+      return
     }
     val lock = tryLockOneLabel(eMInstanceLabel, -1, Utils.getJvmUser)
     try {
+      labelResourceService.removeResourceByLabel(eMInstanceLabel)
       labelResourceService.setLabelResource(
         eMInstanceLabel,
         resource,
@@ -190,8 +211,8 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
   }
 
   /**
-   * The registration method is mainly used to notify all RM nodes (including the node), and the
-   * instance is offline. 该注册方法，主要是用于通知所有的RM节点（包括本节点），下线该实例
+   * The registration method is mainly used to notify all RM nodes , and the instance is offline.
+   * 该注册方法，主要是用于通知所有的RM节点（包括本节点），下线该实例
    */
   override def unregister(serviceInstance: ServiceInstance): Unit = {
 
@@ -199,7 +220,6 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       LabelBuilderFactoryContext.getLabelBuilderFactory.createLabel(classOf[EMInstanceLabel])
     eMInstanceLabel.setServiceName(serviceInstance.getApplicationName)
     eMInstanceLabel.setInstance(serviceInstance.getInstance)
-    val ecNodes = nodeManagerPersistence.getEngineNodeByEM(serviceInstance).asScala
     val lock = tryLockOneLabel(eMInstanceLabel, -1, Utils.getJvmUser)
     try {
       labelResourceService.removeResourceByLabel(eMInstanceLabel)
@@ -217,13 +237,6 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       resourceLockService.unLock(lock)
       logger.info(s"Finished to clear ecm resource:${serviceInstance}")
     }
-    ecNodes.foreach { engineNode =>
-      Utils.tryAndWarn {
-        engineNode.setLabels(nodeLabelService.getNodeLabels(engineNode.getServiceInstance))
-        engineNode.setNodeStatus(NodeStatus.Failed)
-        engineStopService.engineConnInfoClear(engineNode)
-      }
-    }
     logger.info(s"Finished to clear ec for ecm ${serviceInstance}")
   }
 
@@ -236,9 +249,10 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
    */
   override def requestResource(
       labels: util.List[Label[_]],
-      resource: NodeResource
+      resource: NodeResource,
+      engineCreateRequest: EngineCreateRequest
   ): ResultResource = {
-    requestResource(labels, resource, -1)
+    requestResource(labels, resource, engineCreateRequest, -1)
   }
 
   /**
@@ -253,6 +267,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
   override def requestResource(
       labels: util.List[Label[_]],
       resource: NodeResource,
+      engineCreateRequest: EngineCreateRequest,
       wait: Long
   ): ResultResource = {
     val labelContainer = labelResourceService.enrichLabels(labels)
@@ -262,13 +277,15 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
     val resourceLabels = labelContainer.getResourceLabels.asScala
     val persistenceLocks = new ArrayBuffer[PersistenceLock]()
     val emInstanceLabel = labelContainer.getEMInstanceLabel
-    val userCreatorEngineTypeLabel = labelContainer.getCombinedUserCreatorEngineTypeLabel
+    val userCreatorEngineTypeLabel = labelContainer.getCombinedResourceLabel
 
     Utils.tryFinally {
       // check ecm resource if not enough return
       Utils.tryCatch {
         labelContainer.setCurrentLabel(emInstanceLabel)
-        if (!requestResourceService.canRequest(labelContainer, resource)) {
+        // set externalResourceService for get yarn resource
+        requestResourceService.setExternalResourceService(externalResourceService)
+        if (!requestResourceService.canRequest(labelContainer, resource, engineCreateRequest)) {
           return NotEnoughResource(s"Labels:${emInstanceLabel.getStringValue} not enough resource")
         }
       } {
@@ -285,8 +302,10 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
         )
       )
       Utils.tryCatch {
+        // set externalResourceService for get yarn resource
+        requestResourceService.setExternalResourceService(externalResourceService)
         labelContainer.setCurrentLabel(userCreatorEngineTypeLabel)
-        if (!requestResourceService.canRequest(labelContainer, resource)) {
+        if (!requestResourceService.canRequest(labelContainer, resource, engineCreateRequest)) {
           return NotEnoughResource(
             s"Labels:${userCreatorEngineTypeLabel.getStringValue} not enough resource"
           )
@@ -304,14 +323,16 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
         labelContainer.setCurrentLabel(label)
         val labelResource = labelResourceService.getLabelResource(label)
         if (labelResource != null) {
-          labelResource.setLeftResource(labelResource.getLeftResource - resource.getLockedResource)
+          labelResource.setLeftResource(
+            labelResource.getLeftResource.minus(resource.getLockedResource)
+          )
           labelResource.setLockedResource(
-            labelResource.getLockedResource + resource.getLockedResource
+            labelResource.getLockedResource.add(resource.getLockedResource)
           )
           labelResourceService.setLabelResource(
             label,
             labelResource,
-            labelContainer.getCombinedUserCreatorEngineTypeLabel.getStringValue
+            labelContainer.getCombinedResourceLabel.getStringValue
           )
           logger.info(s"ResourceChanged:${label.getStringValue} --> ${labelResource}")
           resourceCheck(label, labelResource)
@@ -320,22 +341,19 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
     } {
       persistenceLocks.foreach(resourceLockService.unLock)
     }
-    // record engine locked resource
-    val tickedId = UUID.randomUUID().toString
-    resourceLogService.recordUserResourceAction(
-      labelContainer,
-      tickedId,
-      ChangeType.ENGINE_REQUEST,
-      resource.getLockedResource
-    )
+
+    // add ec node
+    val tickedId = RMUtils.getECTicketID
     val emNode = new AMEMNode
     emNode.setServiceInstance(labelContainer.getEMInstanceLabel.getServiceInstance)
     val engineNode = new AMEngineNode
     engineNode.setEMNode(emNode)
     engineNode.setServiceInstance(ServiceInstance(labelContainer.getEngineServiceName, tickedId))
     engineNode.setNodeResource(resource)
+    engineNode.setTicketId(tickedId)
     nodeManagerPersistence.addEngineNode(engineNode)
 
+    // add labels
     val engineInstanceLabel =
       LabelBuilderFactoryContext.getLabelBuilderFactory.createLabel(classOf[EngineInstanceLabel])
     engineInstanceLabel.setServiceName(labelContainer.getEngineServiceName)
@@ -343,10 +361,19 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
 
     nodeLabelService.addLabelToNode(engineNode.getServiceInstance, engineInstanceLabel)
 
+    // add ec resource
     labelResourceService.setEngineConnLabelResource(
       engineInstanceLabel,
       resource,
-      labelContainer.getCombinedUserCreatorEngineTypeLabel.getStringValue
+      labelContainer.getCombinedResourceLabel.getStringValue
+    )
+    // record engine locked resource
+    labelContainer.getLabels.add(engineInstanceLabel)
+    resourceLogService.recordUserResourceAction(
+      labelContainer,
+      tickedId,
+      ChangeType.ENGINE_REQUEST,
+      resource.getLockedResource
     )
 
     val persistenceLabel = labelFactory.convertLabel(engineInstanceLabel, classOf[PersistenceLabel])
@@ -410,8 +437,8 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       )
     }
     if (
-        lockedResource == null || lockedResource.getLockedResource <= Resource.initResource(
-          lockedResource.getResourceType
+        lockedResource == null || !lockedResource.getLockedResource.moreThan(
+          Resource.initResource(lockedResource.getResourceType)
         )
     ) {
       throw new RMErrorException(
@@ -423,7 +450,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       s"resourceUsed ready:${labelContainer.getEMInstanceLabel.getServiceInstance}, used resource ${lockedResource.getLockedResource}"
     )
     val addedResource =
-      Resource.initResource(lockedResource.getResourceType) + lockedResource.getLockedResource
+      Resource.initResource(lockedResource.getResourceType).add(lockedResource.getLockedResource)
 
     val engineInstanceLabel: EngineInstanceLabel = labelContainer.getEngineInstanceLabel
     Utils.tryCatch {
@@ -433,7 +460,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       labelResourceService.setLabelResource(
         engineInstanceLabel,
         lockedResource,
-        labelContainer.getCombinedUserCreatorEngineTypeLabel.getStringValue
+        labelContainer.getCombinedResourceLabel.getStringValue
       )
       resourceLogService.success(
         ChangeType.ENGINE_INIT,
@@ -457,15 +484,15 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
             labelContainer.setCurrentLabel(label)
             val labelResource = labelResourceService.getLabelResource(label)
             if (labelResource != null) {
-              labelResource.setLockedResource(labelResource.getLockedResource - addedResource)
+              labelResource.setLockedResource(labelResource.getLockedResource.minus(addedResource))
               if (null == labelResource.getUsedResource) {
                 labelResource.setUsedResource(Resource.initResource(labelResource.getResourceType))
               }
-              labelResource.setUsedResource(labelResource.getUsedResource + addedResource)
+              labelResource.setUsedResource(labelResource.getUsedResource.add(addedResource))
               labelResourceService.setLabelResource(
                 label,
                 labelResource,
-                labelContainer.getCombinedUserCreatorEngineTypeLabel.getStringValue
+                labelContainer.getCombinedResourceLabel.getStringValue
               )
               labelResourceSet.add(
                 new LabelResourceMapping(label, addedResource, ResourceOperationType.USED)
@@ -475,11 +502,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
           } {
             resourceLockService.unLock(persistenceLock)
           }
-          if (
-              label.getClass.isAssignableFrom(
-                labelContainer.getCombinedUserCreatorEngineTypeLabel.getClass
-              )
-          ) {
+          if (label.getClass.isAssignableFrom(labelContainer.getCombinedResourceLabel.getClass)) {
             resourceLogService.recordUserResourceAction(
               labelContainer,
               persistenceResource.getTicketId,
@@ -502,9 +525,9 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
     if (labelResource != null && label != null) {
       val resourceInit = Resource.initResource(labelResource.getResourceType)
       if (
-          labelResource.getLockedResource < resourceInit ||
-          labelResource.getUsedResource < resourceInit ||
-          labelResource.getLeftResource < resourceInit
+          !labelResource.getLockedResource.notLess(resourceInit) ||
+          !labelResource.getUsedResource.notLess(resourceInit) ||
+          !labelResource.getLeftResource.notLess(resourceInit)
       ) {
         logger.info(
           s"found error resource! resource label:${label.getStringValue}, resource:${labelResource}, please check!"
@@ -521,20 +544,20 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       case driverAndYarnResource: DriverAndYarnResource =>
         nodeResource.getUsedResource match {
           case resource: DriverAndYarnResource =>
-            val newYarnResource = resource.yarnResource
+            val newYarnResource = resource.getYarnResource
             val applicationId: String = if (null != newYarnResource) {
-              newYarnResource.applicationId
+              newYarnResource.getApplicationId
             } else {
               null
             }
-            val oriYarnResource = driverAndYarnResource.yarnResource
+            val oriYarnResource = driverAndYarnResource.getYarnResource
             val tmpUsedResource = new DriverAndYarnResource(
-              driverAndYarnResource.loadInstanceResource,
+              driverAndYarnResource.getLoadInstanceResource,
               new YarnResource(
-                oriYarnResource.queueMemory,
-                oriYarnResource.queueCores,
-                oriYarnResource.queueInstances,
-                oriYarnResource.queueName,
+                oriYarnResource.getQueueMemory,
+                oriYarnResource.getQueueCores,
+                oriYarnResource.getQueueInstances,
+                oriYarnResource.getQueueName,
                 applicationId
               )
             )
@@ -545,11 +568,11 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
         nodeResource.getUsedResource match {
           case resource: YarnResource =>
             val tmpYarnResource = new YarnResource(
-              yarnResource.queueMemory,
-              yarnResource.queueCores,
-              yarnResource.queueInstances,
-              yarnResource.queueName,
-              resource.applicationId
+              yarnResource.getQueueMemory,
+              yarnResource.getQueueCores,
+              yarnResource.getQueueInstances,
+              yarnResource.getQueueName,
+              resource.getApplicationId
             )
             lockedResource.setUsedResource(tmpYarnResource)
           case _ =>
@@ -568,16 +591,18 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
         val resource = labelResourceService.getLabelResource(labelResourceMapping.getLabel())
         labelResourceMapping.getResourceOperationType match {
           case LOCK =>
-            resource.setLeftResource(resource.getLeftResource + labelResourceMapping.getResource())
+            resource.setLeftResource(
+              resource.getLeftResource.add(labelResourceMapping.getResource())
+            )
             resource.setLockedResource(
-              resource.getLockedResource - labelResourceMapping.getResource()
+              resource.getLockedResource.minus(labelResourceMapping.getResource())
             )
           case USED =>
             resource.setLockedResource(
-              resource.getLeftResource + labelResourceMapping.getResource()
+              resource.getLeftResource.add(labelResourceMapping.getResource())
             )
             resource.setUsedResource(
-              resource.getLockedResource - labelResourceMapping.getResource()
+              resource.getLockedResource.minus(labelResourceMapping.getResource())
             )
           case _ =>
         }
@@ -593,7 +618,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
     }
   }
 
-  private def tryLockOneLabel(
+  override def tryLockOneLabel(
       label: Label[_],
       timeOut: Long = -1,
       user: String
@@ -670,31 +695,36 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
               if (labelResource != null) {
                 if (label.isInstanceOf[EMInstanceLabel]) timeCheck(labelResource, usedResource)
                 if (
-                    null != usedResource.getUsedResource && usedResource.getUsedResource != Resource
-                      .initResource(usedResource.getResourceType)
+                    null != usedResource.getUsedResource && usedResource.getUsedResource.moreThan(
+                      Resource
+                        .initResource(usedResource.getResourceType)
+                    )
                 ) {
                   labelResource.setUsedResource(
-                    labelResource.getUsedResource - usedResource.getUsedResource
+                    labelResource.getUsedResource.minus(usedResource.getUsedResource)
                   )
                   labelResource.setLeftResource(
-                    labelResource.getLeftResource + usedResource.getUsedResource
+                    labelResource.getLeftResource.add(usedResource.getUsedResource)
                   )
                 }
                 if (
-                    null != usedResource.getLockedResource && usedResource.getLockedResource != Resource
-                      .initResource(usedResource.getResourceType)
+                    null != usedResource.getLockedResource && usedResource.getLockedResource
+                      .moreThan(
+                        Resource
+                          .initResource(usedResource.getResourceType)
+                      )
                 ) {
                   labelResource.setLockedResource(
-                    labelResource.getLockedResource - usedResource.getLockedResource
+                    labelResource.getLockedResource.minus(usedResource.getLockedResource)
                   )
                   labelResource.setLeftResource(
-                    labelResource.getLeftResource + usedResource.getLockedResource
+                    labelResource.getLeftResource.add(usedResource.getLockedResource)
                   )
                 }
                 labelResourceService.setLabelResource(
                   label,
                   labelResource,
-                  labelContainer.getCombinedUserCreatorEngineTypeLabel.getStringValue
+                  labelContainer.getCombinedResourceLabel.getStringValue
                 )
                 resourceCheck(label, labelResource)
               }
@@ -714,11 +744,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
                 heartbeatMsgMetrics = oldMetrics.getHeartBeatMsg
               }
             }
-            if (
-                label.getClass.isAssignableFrom(
-                  labelContainer.getCombinedUserCreatorEngineTypeLabel.getClass
-                )
-            ) {
+            if (label.getClass.isAssignableFrom(labelContainer.getCombinedResourceLabel.getClass)) {
               resourceLogService.recordUserResourceAction(
                 labelContainer,
                 persistenceResource.getTicketId,
@@ -803,7 +829,7 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
    */
 
   override def getResourceInfo(serviceInstances: Array[ServiceInstance]): ResourceInfo = {
-    val resourceInfo = new ResourceInfo(Lists.newArrayList())
+    val resourceInfo = ResourceInfo(Lists.newArrayList())
     serviceInstances.foreach({ serviceInstance =>
       val rmNode = new InfoRMNode
       var aggregatedResource: NodeResource = null
@@ -853,8 +879,8 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
       if (
           usedResource != null
           && usedResource.getLockedResource != null
-          && usedResource.getLockedResource > Resource.getZeroResource(
-            usedResource.getLockedResource
+          && usedResource.getLockedResource.moreThan(
+            Resource.getZeroResource(usedResource.getLockedResource)
           )
       ) {
         val dbEngineInstanceLabel = labelManagerPersistence.getLabel(persistenceEngineLabel.getId)
@@ -886,4 +912,39 @@ class DefaultResourceManager extends ResourceManager with Logging with Initializ
 
   }
 
+  /**
+   * Can request resource
+   *
+   * @param labels
+   * @param resource
+   * @param engineCreateRequest
+   * @return
+   */
+  override def canRequestResource(
+      labels: util.List[Label[_]],
+      resource: NodeResource,
+      engineCreateRequest: EngineCreateRequest
+  ): CanCreateECRes = {
+    val labelContainer = labelResourceService.enrichLabels(labels)
+
+    // check resource with lock
+    val requestResourceService = getRequestResourceService(resource.getResourceType)
+    if (
+        labelContainer.getEMInstanceLabel == null || labelContainer.getCombinedResourceLabel == null
+    ) {
+      val canCreateECRes = new CanCreateECRes
+      canCreateECRes.setCanCreateEC(false)
+      canCreateECRes.setReason("EMLabel,userCreator and engineTypeLabel cannot null")
+    }
+    requestResourceService.canRequestResource(labelContainer, resource, engineCreateRequest)
+  }
+
+  override def resetResource(label: PersistenceLabel, resource: NodeResource): Unit = {
+    labelResourceService.setLabelResource(label, resource, label.getStringValue)
+  }
+
+  override def unLock(persistenceLock: PersistenceLock): Unit = {
+    resourceLockService.unLock(persistenceLock)
+  }
+
 }
