@@ -34,6 +34,7 @@ import org.apache.linkis.engineplugin.hive.errorcode.HiveErrorCodeSummary.{
 }
 import org.apache.linkis.engineplugin.hive.exception.HiveQueryFailedException
 import org.apache.linkis.engineplugin.hive.progress.HiveProgressHelper
+import org.apache.linkis.governance.common.constant.job.JobRequestConstants
 import org.apache.linkis.governance.common.paser.SQLCodeParser
 import org.apache.linkis.governance.common.utils.JobUtils
 import org.apache.linkis.hadoop.common.conf.HadoopConf
@@ -56,6 +57,7 @@ import org.apache.hadoop.hive.common.HiveInterruptUtils
 import org.apache.hadoop.hive.conf.HiveConf
 import org.apache.hadoop.hive.metastore.api.{FieldSchema, Schema}
 import org.apache.hadoop.hive.ql.{Driver, QueryPlan}
+import org.apache.hadoop.hive.ql.exec.Task.TaskState
 import org.apache.hadoop.hive.ql.exec.Utilities
 import org.apache.hadoop.hive.ql.exec.mr.HadoopJobExecHelper
 import org.apache.hadoop.hive.ql.exec.tez.TezJobExecHelper
@@ -143,49 +145,82 @@ class HiveEngineConnExecutor(
     val realCode = code.trim()
     LOG.info(s"hive client begins to run hql code:\n ${realCode.trim}")
     val jobId = JobUtils.getJobIdFromMap(engineExecutorContext.getProperties)
+
     if (StringUtils.isNotBlank(jobId)) {
-      LOG.info(s"set mapreduce.job.tags=LINKIS_$jobId")
-      hiveConf.set("mapreduce.job.tags", s"LINKIS_$jobId")
+      val jobTags = JobUtils.getJobSourceTagsFromObjectMap(engineExecutorContext.getProperties)
+      val tags = if (StringUtils.isAsciiPrintable(jobTags)) {
+        s"LINKIS_$jobId,$jobTags"
+      } else {
+        s"LINKIS_$jobId"
+      }
+      LOG.info(s"set mapreduce.job.tags=$tags")
+      hiveConf.set("mapreduce.job.tags", tags)
     }
+
     if (realCode.trim.length > 500) {
       engineExecutorContext.appendStdout(s"$getId >> ${realCode.trim.substring(0, 500)} ...")
     } else engineExecutorContext.appendStdout(s"$getId >> ${realCode.trim}")
     val tokens = realCode.trim.split("""\s+""")
     SessionState.setCurrentSessionState(sessionState)
     sessionState.setLastCommand(code)
+    if (
+        engineExecutorContext.getCurrentParagraph == 1 && engineExecutorContext.getProperties
+          .containsKey(JobRequestConstants.LINKIS_JDBC_DEFAULT_DB)
+    ) {
+      val defaultDB =
+        engineExecutorContext.getProperties
+          .get(JobRequestConstants.LINKIS_JDBC_DEFAULT_DB)
+          .asInstanceOf[String]
+      logger.info(s"set default DB to $defaultDB")
+      sessionState.setCurrentDatabase(defaultDB)
+    }
     val proc = CommandProcessorFactory.get(tokens, hiveConf)
     this.proc = proc
     LOG.debug("ugi is " + ugi.getUserName)
-    ugi.doAs(new PrivilegedExceptionAction[ExecuteResponse]() {
-      override def run(): ExecuteResponse = {
-        proc match {
-          case any if HiveDriverProxy.isDriver(any) =>
-            logger.info(s"driver is $any")
-            thread = Thread.currentThread()
-            driver = new HiveDriverProxy(any)
-            executeHQL(realCode, driver)
-          case _ =>
-            val resp = proc.run(realCode.substring(tokens(0).length).trim)
-            val result = new String(baos.toByteArray)
-            logger.info("RESULT => {}", result)
-            engineExecutorContext.appendStdout(result)
-            baos.reset()
-            if (resp.getResponseCode != 0) {
-              clearCurrentProgress()
+    Utils.tryFinally {
+      ugi.doAs(new PrivilegedExceptionAction[ExecuteResponse]() {
+        override def run(): ExecuteResponse = {
+          proc match {
+            case any if HiveDriverProxy.isDriver(any) =>
+              logger.info(s"driver is $any")
+              thread = Thread.currentThread()
+              driver = new HiveDriverProxy(any)
+              executeHQL(realCode, driver)
+            case _ =>
+              val resp = proc.run(realCode.substring(tokens(0).length).trim)
+              val result = new String(baos.toByteArray)
+              logger.info("RESULT => {}", result)
+              engineExecutorContext.appendStdout(result)
+              baos.reset()
+              if (resp.getResponseCode != 0) {
+                clearCurrentProgress()
+                HiveProgressHelper.clearHiveProgress()
+                onComplete()
+                singleSqlProgressMap.clear()
+                HiveProgressHelper.storeSingleSQLProgress(0.0f)
+                throw resp.getException
+              }
               HiveProgressHelper.clearHiveProgress()
+              HiveProgressHelper.storeSingleSQLProgress(0.0f)
               onComplete()
               singleSqlProgressMap.clear()
-              HiveProgressHelper.storeSingleSQLProgress(0.0f)
-              throw resp.getException
-            }
-            HiveProgressHelper.clearHiveProgress()
-            HiveProgressHelper.storeSingleSQLProgress(0.0f)
-            onComplete()
-            singleSqlProgressMap.clear()
-            SuccessExecuteResponse()
+              SuccessExecuteResponse()
+          }
+        }
+      })
+    } {
+      if (this.driver != null) {
+        Utils.tryQuietly {
+          driver.close()
+          this.driver = null
+          val ss = SessionState.get()
+          if (ss != null) {
+            ss.deleteTmpOutputFile()
+            ss.deleteTmpErrOutputFile()
+          }
         }
       }
-    })
+    }
   }
 
   private def executeHQL(realCode: String, driver: HiveDriverProxy): ExecuteResponse = {
@@ -204,9 +239,11 @@ class HiveEngineConnExecutor(
             var compileRet = -1
             Utils.tryCatch {
               compileRet = driver.compile(realCode)
-              logger.info(s"driver compile realCode : ${realCode} finished, status : ${compileRet}")
+              logger.info(
+                s"driver compile realCode : \n ${realCode} \n finished, status : ${compileRet}"
+              )
               if (0 != compileRet) {
-                logger.warn(s"compile realCode : ${realCode} error status : ${compileRet}")
+                logger.warn(s"compile realCode : \n ${realCode} \n error status : ${compileRet}")
                 throw HiveQueryFailedException(
                   COMPILE_HIVE_QUERY_ERROR.getErrorCode,
                   COMPILE_HIVE_QUERY_ERROR.getErrorDesc
@@ -465,17 +502,35 @@ class HiveEngineConnExecutor(
       val totalSQLs = engineExecutorContext.getTotalParagraph
       val currentSQL = engineExecutorContext.getCurrentParagraph
       val currentBegin = (currentSQL - 1) / totalSQLs.asInstanceOf[Float]
-      HadoopJobExecHelper.runningJobs synchronized {
-        HadoopJobExecHelper.runningJobs.asScala foreach { runningJob =>
-          val name = runningJob.getID.toString
-          val _progress = runningJob.reduceProgress() + runningJob.mapProgress()
-          singleSqlProgressMap.put(name, _progress / 2)
+      val finishedStage =
+        if (null != driver && null != driver.getPlan() && !driver.getPlan().getRootTasks.isEmpty) {
+          Utils.tryQuietly(
+            Utilities
+              .getMRTasks(driver.getPlan().getRootTasks)
+              .asScala
+              .count(task => task.isMapRedTask && task.getTaskState == TaskState.FINISHED)
+          )
+        } else {
+          0
+        }
+      var totalProgress: Float = 0.0f
+      if (!HadoopJobExecHelper.runningJobs.isEmpty) {
+        val runningJob = HadoopJobExecHelper.runningJobs.get(0)
+        val _progress = Utils.tryCatch(runningJob.reduceProgress() + runningJob.mapProgress()) {
+          case e: Exception =>
+            logger.info(s"Failed to get job(${runningJob.getJobName}) progress ", e)
+            0.2f
+        }
+        if (!_progress.isNaN) {
+          totalProgress = _progress / 2
         }
       }
-      var totalProgress: Float = 0.0f
+      logger.info(
+        s"Running stage  progress is $totalProgress, and finished stage is $finishedStage"
+      )
       val hiveRunJobs = if (numberOfMRJobs <= 0) 1 else numberOfMRJobs
-      singleSqlProgressMap.asScala foreach { case (_name, _progress) =>
-        totalProgress += _progress
+      if (finishedStage <= hiveRunJobs) {
+        totalProgress = totalProgress + finishedStage
       }
       try {
         totalProgress = totalProgress / (hiveRunJobs * totalSQLs)
@@ -484,10 +539,10 @@ class HiveEngineConnExecutor(
         case _ => totalProgress = 0.0f
       }
 
-      logger.debug(s"hive progress is $totalProgress")
       val newProgress =
         if (totalProgress.isNaN || totalProgress.isInfinite) currentBegin
         else totalProgress + currentBegin
+      logger.info(s"Hive progress is $newProgress, and finished stage is $finishedStage")
       val oldProgress = ProgressUtils.getOldProgress(this.engineExecutorContext)
       if (newProgress < oldProgress) oldProgress
       else {
@@ -549,9 +604,6 @@ class HiveEngineConnExecutor(
         HadoopJobExecHelper.killRunningJobs()
         Utils.tryQuietly(HiveInterruptUtils.interrupt())
         Utils.tryAndWarn(driver.close())
-        if (null != thread) {
-          Utils.tryAndWarn(thread.interrupt())
-        }
       case "tez" =>
         Utils.tryQuietly(TezJobExecHelper.killRunningJobs())
         driver.close()
@@ -640,12 +692,10 @@ class HiveDriverProxy(driver: Any) extends Logging {
   }
 
   def getResults(res: util.List[_]): Boolean = {
-    Utils.tryAndWarn {
-      driver.getClass
-        .getMethod("getResults", classOf[util.List[_]])
-        .invoke(driver, res.asInstanceOf[AnyRef])
-        .asInstanceOf[Boolean]
-    }
+    driver.getClass
+      .getMethod("getResults", classOf[util.List[_]])
+      .invoke(driver, res.asInstanceOf[AnyRef])
+      .asInstanceOf[Boolean]
   }
 
   def close(): Unit = {
