@@ -17,9 +17,9 @@
 
 package org.apache.linkis.configuration.service
 
-import org.apache.linkis.common.utils.Logging
+import org.apache.linkis.common.utils.{Logging, Utils}
 import org.apache.linkis.configuration.conf.Configuration
-import org.apache.linkis.configuration.dao.{ConfigMapper, LabelMapper}
+import org.apache.linkis.configuration.dao.{ConfigKeyLimitForUserMapper, ConfigMapper, LabelMapper}
 import org.apache.linkis.configuration.entity._
 import org.apache.linkis.configuration.exception.ConfigurationException
 import org.apache.linkis.configuration.util.{LabelEntityParser, LabelParameterParser}
@@ -42,6 +42,7 @@ import org.springframework.stereotype.Service
 import org.springframework.transaction.annotation.Transactional
 import org.springframework.util.CollectionUtils
 
+import java.text.MessageFormat
 import java.util
 
 import scala.collection.JavaConverters._
@@ -57,6 +58,8 @@ class ConfigurationService extends Logging {
 
   @Autowired private var validatorManager: ValidatorManager = _
 
+  @Autowired private var configKeyLimitForUserMapper: ConfigKeyLimitForUserMapper = _
+
   private val combinedLabelBuilder: CombinedLabelBuilder = new CombinedLabelBuilder
 
   @Transactional
@@ -93,12 +96,6 @@ class ConfigurationService extends Logging {
     }
   }
 
-  def insertCreator(creator: String): Unit = {
-    val creatorID: Long = configMapper.selectAppIDByAppName(creator)
-    if (creatorID > 0) configMapper.insertCreator(creator)
-    else logger.warn(s"creator${creator} exists")
-  }
-
   def checkAndCreateUserLabel(
       settings: util.List[ConfigKeyValue],
       username: String,
@@ -178,6 +175,33 @@ class ConfigurationService extends Logging {
       createList: util.List[ConfigValue],
       updateList: util.List[ConfigValue]
   ): Any = {
+
+    val configLabel = labelMapper.getLabelById(setting.getConfigLabelId)
+    val combinedLabel = combinedLabelBuilder
+      .buildFromStringValue(configLabel.getLabelKey, configLabel.getStringValue)
+      .asInstanceOf[CombinedLabel]
+    val templateConfigKeyVo =
+      configKeyLimitForUserMapper.selectByLabelAndKeyId(combinedLabel.getStringValue, setting.getId)
+    if (templateConfigKeyVo != null && StringUtils.isNotBlank(templateConfigKeyVo.getMaxValue)) {
+      Utils.tryCatch {
+        val maxValue = Integer.valueOf(templateConfigKeyVo.getMaxValue.replaceAll("[^0-9]", ""))
+        val configValue = Integer.valueOf(setting.getConfigValue.replaceAll("[^0-9]", ""))
+        if (configValue > maxValue) {
+          throw new ConfigurationException(
+            s"Parameter key:${setting.getKey},config value:${setting.getConfigValue} verification failed，exceeds the specified max value:${templateConfigKeyVo.getMaxValue}:(参数校验失败，超过指定的最大值):" +
+              s"${setting.getValidateType}--${setting.getValidateRange}"
+          )
+        }
+      } { case exception: Exception =>
+        if (exception.isInstanceOf[ConfigurationException]) {
+          throw exception
+        } else {
+          logger.warn(
+            s"Failed to check special limit setting for key:${setting.getKey},config value:${setting.getConfigValue}"
+          )
+        }
+      }
+    }
     paramCheck(setting)
     if (setting.getIsUserDefined) {
       val configValue = new ConfigValue
@@ -259,6 +283,12 @@ class ConfigurationService extends Logging {
     combinedLabel.asInstanceOf[CombinedLabelImpl]
   }
 
+  /**
+   * Priority: configs > defaultConfigs
+   * @param configs
+   * @param defaultConfigs
+   * @return
+   */
   def buildTreeResult(
       configs: util.List[ConfigKeyValue],
       defaultConfigs: util.List[ConfigKeyValue] = new util.ArrayList[ConfigKeyValue]()
@@ -269,9 +299,8 @@ class ConfigurationService extends Logging {
         defaultConfig.setIsUserDefined(false)
         configs.asScala.foreach(config => {
           if (config.getKey != null && config.getKey.equals(defaultConfig.getKey)) {
-            if (StringUtils.isNotBlank(config.getConfigValue)) {
-              defaultConfig.setConfigValue(config.getConfigValue)
-            }
+            // configValue also needs to be replaced when the value is empty
+            defaultConfig.setConfigValue(config.getConfigValue)
             defaultConfig.setConfigLabelId(config.getConfigLabelId)
             defaultConfig.setValueId(config.getValueId)
             defaultConfig.setIsUserDefined(true)
@@ -310,7 +339,8 @@ class ConfigurationService extends Logging {
         val engineconfig =
           defaultEngineConfigs.asScala.find(_.getKey.equals(creatorConfig.getKey))
         if (engineconfig.isDefined) {
-          engineconfig.get.setDefaultValue(creatorConfig.getConfigValue)
+          engineconfig.get.setDefaultValue(creatorConfig.getDefaultValue)
+          engineconfig.get.setConfigValue(creatorConfig.getConfigValue)
         } else {
           defaultEngineConfigs.add(creatorConfig)
         }
@@ -346,30 +376,32 @@ class ConfigurationService extends Logging {
     }
     var defaultEngineConfigs: util.List[ConfigKeyValue] = new util.ArrayList[ConfigKeyValue]()
     var defaultCreatorConfigs: util.List[ConfigKeyValue] = new util.ArrayList[ConfigKeyValue]()
+    var defaultUserConfigs: util.List[ConfigKeyValue] = new util.ArrayList[ConfigKeyValue]()
     if (useDefaultConfig) {
-      val defaultCretorLabelList = LabelParameterParser.changeUserToDefault(labelList, false)
-      val defaultCreatorCombinedLabel =
-        combinedLabelBuilder.build("", defaultCretorLabelList).asInstanceOf[CombinedLabelImpl]
-      val defaultCreatorLabel = labelMapper.getLabelByKeyValue(
-        defaultCreatorCombinedLabel.getLabelKey,
-        defaultCreatorCombinedLabel.getStringValue
+      // query *-ide  default conf
+      val defaultCreatorLabel = getConfByLabelList(
+        LabelParameterParser.changeUserToDefault(labelList, false)
       )
       if (defaultCreatorLabel != null) {
         defaultCreatorConfigs = getConfigByLabelId(defaultCreatorLabel.getId, language)
       }
-      val defaultEngineLabelList = LabelParameterParser.changeUserToDefault(labelList)
-      val defaultEngineCombinedLabel =
-        combinedLabelBuilder.build("", defaultEngineLabelList).asInstanceOf[CombinedLabelImpl]
-      val defaultEngineLabel = labelMapper.getLabelByKeyValue(
-        defaultEngineCombinedLabel.getLabelKey,
-        defaultEngineCombinedLabel.getStringValue
+      // query user-*  default conf
+      val defaultUserLabel = getConfByLabelList(
+        LabelParameterParser.changeUserToDefault(labelList, true, false)
+      )
+      if (defaultUserLabel != null) {
+        defaultUserConfigs = getConfigByLabelId(defaultUserLabel.getId, language)
+      }
+      // query *-*  default conf
+      val defaultEngineLabel = getConfByLabelList(
+        LabelParameterParser.changeUserToDefault(labelList)
       )
       if (defaultEngineLabel != null) {
         defaultEngineConfigs = getConfigByLabelId(defaultEngineLabel.getId, language)
       }
       if (CollectionUtils.isEmpty(defaultEngineConfigs)) {
         logger.warn(
-          s"The default configuration is empty. Please check the default configuration information in the database table(默认配置为空,请检查数据库表中关于标签${defaultEngineCombinedLabel.getStringValue}的默认配置信息是否完整)"
+          s"The default configuration is empty. Please check the default configuration information in the database table(默认配置为空,请检查数据库表中关于标签 *-* 的默认配置信息是否完整)"
         )
       }
       val userCreatorLabel = labelList.asScala
@@ -379,10 +411,47 @@ class ConfigurationService extends Logging {
       if (Configuration.USE_CREATOR_DEFAULE_VALUE && userCreatorLabel.getCreator != "*") {
         replaceCreatorToEngine(defaultCreatorConfigs, defaultEngineConfigs)
       }
+      if (Configuration.USE_USER_DEFAULE_VALUE && userCreatorLabel.getUser != "*") {
+        replaceCreatorToEngine(defaultUserConfigs, defaultEngineConfigs)
+      }
     }
+
+    // add special config limit info
+    if (defaultEngineConfigs.size() > 0) {
+      val keyIdList = defaultEngineConfigs.asScala.toStream
+        .map(e => {
+          e.getId
+        })
+        .toList
+        .asJava
+      val limitList =
+        configKeyLimitForUserMapper.selectByLabelAndKeyIds(combinedLabel.getStringValue, keyIdList)
+      defaultEngineConfigs.asScala.foreach(entity => {
+        val keyId = entity.getId
+        val res = limitList.asScala.filter(v => v.getKeyId == keyId).toList.asJava
+        if (res.size() > 0) {
+          val specialMap = new util.HashMap[String, String]()
+          val maxValue = res.get(0).getMaxValue
+          if (StringUtils.isNotBlank(maxValue)) {
+            specialMap.put("maxValue", maxValue)
+            entity.setSpecialLimit(specialMap)
+          }
+        }
+      })
+    } else {
+      logger.warn(
+        s"The configuration is empty. Please check the configuration information in the database table(配置为空,请检查数据库表中关于标签${combinedLabel.getStringValue}的配置信息是否完整)"
+      )
+    }
+
     (configs, defaultEngineConfigs)
   }
 
+  private def getConfByLabelList(labelList: java.util.List[Label[_]]): ConfigLabel = {
+    val combinedLabel = combinedLabelBuilder.build("", labelList).asInstanceOf[CombinedLabelImpl]
+    labelMapper.getLabelByKeyValue(combinedLabel.getLabelKey, combinedLabel.getStringValue)
+  }
+
   /**
    * Priority: User Configuration-->Creator's Default Engine Configuration-->Default Engine
    * Configuration For database initialization: you need to modify the linkis.dml file--associated
